========================
:mod:`oujago.utils.data`
========================

.. automodule:: oujago.utils.data


.. autosummary::


Detailed Description
--------------------

.. autofunction:: pad_sequences

